.. -*- coding: utf-8 -*-

Bibliography
============

.. [BMD06] H. Bombin and M. A. Martin-Delgado. "Topological quantum distillation". Phys. Rev. Lett. 97 (Nov. 2006), p. 180501. doi: 10.1103/PhysRevLett.97.180501. :arxiv:`quant-ph/0605138`

.. [BMD07] H. Bombin and M. A. Martin-Delgado. "Optimal Resources for Topological 2D Stabilizer Codes: Comparative Study". Phys. Rev. A 76 (July 2007), p. 012305. doi: 10.1103/PhysRevA.76.012305. :arxiv:`quant-ph/0703272`

.. [Den+02] Eric Dennis, Alexei Kitaev, Andrew Landahl, and John Preskill. "Topological quantum memory". In: J. Math. Phys. 43.9 (Sept. 2002), pp. 4452–4505. doi: 10.1063/1.1499754. :arxiv:`quant-ph/0110143`.

.. [Kit97b] A. Yu. Kitaev. "Quantum computations: algorithms and error correction". Russian Math. Surveys 52.6 (1997), pp. 1191–1249. doi: 10.1070/RM1997v052n06ABEH002155.

.. [LRA14] Andrew J. Landahl and Ciarán Ryan-Anderson. "Quantum computing by color-code lattice surgery". 2014. :arxiv:`1407.5103`

.. [RA18] Ciarán Ryan-Anderson. "Quantum Algorithms, Architecture, and Error Correction". 2018. :arxiv:`1812.04735`
